==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/apprunner_service/ApprunnerServiceNetworkConfiguration.java <==
package com.hashicorp.cdktf.providers.aws.apprunner_service;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:51.616Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.apprunnerService.ApprunnerServiceNetworkConfiguration")
@software.amazon.jsii.Jsii.Proxy(ApprunnerServiceNetworkConfiguration.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ApprunnerServiceNetworkConfiguration extends software.amazon.jsii.JsiiSerializable {

    /**
     * egress_configuration block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/apprunner_service#egress_configuration ApprunnerService#egress_configuration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration getEgressConfiguration() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ApprunnerServiceNetworkConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ApprunnerServiceNetworkConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ApprunnerServiceNetworkConfiguration> {
        com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration egressConfiguration;

        /**
         * Sets the value of {@link ApprunnerServiceNetworkConfiguration#getEgressConfiguration}
         * @param egressConfiguration egress_configuration block.
         *                            Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/apprunner_service#egress_configuration ApprunnerService#egress_configuration}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder egressConfiguration(com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration egressConfiguration) {
            this.egressConfiguration = egressConfiguration;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ApprunnerServiceNetworkConfiguration}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ApprunnerServiceNetworkConfiguration build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ApprunnerServiceNetworkConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ApprunnerServiceNetworkConfiguration {
        private final com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration egressConfiguration;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.egressConfiguration = software.amazon.jsii.Kernel.get(this, "egressConfiguration", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.egressConfiguration = builder.egressConfiguration;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration getEgressConfiguration() {
            return this.egressConfiguration;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getEgressConfiguration() != null) {
                data.set("egressConfiguration", om.valueToTree(this.getEgressConfiguration()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.apprunnerService.ApprunnerServiceNetworkConfiguration"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ApprunnerServiceNetworkConfiguration.Jsii$Proxy that = (ApprunnerServiceNetworkConfiguration.Jsii$Proxy) o;

            return this.egressConfiguration != null ? this.egressConfiguration.equals(that.egressConfiguration) : that.egressConfiguration == null;
        }

        @Override
        public final int hashCode() {
            int result = this.egressConfiguration != null ? this.egressConfiguration.hashCode() : 0;
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/apprunner_service/ApprunnerServiceNetworkConfiguration.java <==
package com.hashicorp.cdktf.providers.aws.apprunner_service;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:07.404Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.apprunnerService.ApprunnerServiceNetworkConfiguration")
@software.amazon.jsii.Jsii.Proxy(ApprunnerServiceNetworkConfiguration.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ApprunnerServiceNetworkConfiguration extends software.amazon.jsii.JsiiSerializable {

    /**
     * egress_configuration block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/apprunner_service#egress_configuration ApprunnerService#egress_configuration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration getEgressConfiguration() {
        return null;
    }

    /**
     * ingress_configuration block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/apprunner_service#ingress_configuration ApprunnerService#ingress_configuration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationIngressConfiguration getIngressConfiguration() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ApprunnerServiceNetworkConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ApprunnerServiceNetworkConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ApprunnerServiceNetworkConfiguration> {
        com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration egressConfiguration;
        com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationIngressConfiguration ingressConfiguration;

        /**
         * Sets the value of {@link ApprunnerServiceNetworkConfiguration#getEgressConfiguration}
         * @param egressConfiguration egress_configuration block.
         *                            Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/apprunner_service#egress_configuration ApprunnerService#egress_configuration}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder egressConfiguration(com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration egressConfiguration) {
            this.egressConfiguration = egressConfiguration;
            return this;
        }

        /**
         * Sets the value of {@link ApprunnerServiceNetworkConfiguration#getIngressConfiguration}
         * @param ingressConfiguration ingress_configuration block.
         *                             Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/apprunner_service#ingress_configuration ApprunnerService#ingress_configuration}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ingressConfiguration(com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationIngressConfiguration ingressConfiguration) {
            this.ingressConfiguration = ingressConfiguration;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ApprunnerServiceNetworkConfiguration}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ApprunnerServiceNetworkConfiguration build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ApprunnerServiceNetworkConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ApprunnerServiceNetworkConfiguration {
        private final com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration egressConfiguration;
        private final com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationIngressConfiguration ingressConfiguration;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.egressConfiguration = software.amazon.jsii.Kernel.get(this, "egressConfiguration", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration.class));
            this.ingressConfiguration = software.amazon.jsii.Kernel.get(this, "ingressConfiguration", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationIngressConfiguration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.egressConfiguration = builder.egressConfiguration;
            this.ingressConfiguration = builder.ingressConfiguration;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration getEgressConfiguration() {
            return this.egressConfiguration;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationIngressConfiguration getIngressConfiguration() {
            return this.ingressConfiguration;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getEgressConfiguration() != null) {
                data.set("egressConfiguration", om.valueToTree(this.getEgressConfiguration()));
            }
            if (this.getIngressConfiguration() != null) {
                data.set("ingressConfiguration", om.valueToTree(this.getIngressConfiguration()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.apprunnerService.ApprunnerServiceNetworkConfiguration"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ApprunnerServiceNetworkConfiguration.Jsii$Proxy that = (ApprunnerServiceNetworkConfiguration.Jsii$Proxy) o;

            if (this.egressConfiguration != null ? !this.egressConfiguration.equals(that.egressConfiguration) : that.egressConfiguration != null) return false;
            return this.ingressConfiguration != null ? this.ingressConfiguration.equals(that.ingressConfiguration) : that.ingressConfiguration == null;
        }

        @Override
        public final int hashCode() {
            int result = this.egressConfiguration != null ? this.egressConfiguration.hashCode() : 0;
            result = 31 * result + (this.ingressConfiguration != null ? this.ingressConfiguration.hashCode() : 0);
            return result;
        }
    }
}
